==> Config-Files-Simple-0.01.tar.gz: Config-Files-Simple-0.01/lib/Config/Files/Simple/JSON.pm <==
package Config::Files::Simple::JSON;

=encoding UTF-8
 
=head1 NAME
 
Config::Files::Simple::JSON - Yet another config file reader.

=head1 VERSION

version 0.01

=cut

our $VERSION = '0.01';    # VERSION

use utf8;
use strict;
use warnings;

=head1 SUBROUTINES/METHODS

=head2 new

Constructor

=cut

sub new {
    my $class = shift;
    my $self  = {};
    bless $self, $class;
}

=head2 config_file

Read configuration file from given path.

=cut

sub config_file {
    if ( !-f $_[1] ) {
        require Carp;
        Carp::cluck "could not find $_[1] file";
        return undef;
    }
    require String::Any::Extensions;
    if ( !String::Any::Extensions::include( $_[1], defined $_[2] ? $_[2] : ['.json'] ) ) {
        require Carp;
        Carp::cluck("$_[1] seems not to be a JSON file.");
    }
    require JSON::Parse;
    return JSON::Parse::json_file_to_perl( $_[1] );
}

1;

__END__

=pod
 
=head1 DESCRIPTION
 
JSON file reader for Config::Files::Simple.
 
=head1 AUTHOR

Mario Zieschang, C<< <mziescha at cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-Config-Files-Simple at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Config-Files-Simple>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Config::Files::Simple


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Config-Files-Simple>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Config-Files-Simple>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Config-Files-Simple>

=item * Search CPAN

L<http://search.cpan.org/dist/Config-Files-Simple/>

=back

=head1 LICENSE AND COPYRIGHT

Copyright 2016 Mario Zieschang.

This program is free software; you can redistribute it and/or modify it
under the terms of the the Artistic License (2.0). You may obtain a
copy of the full license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any use, modification, and distribution of the Standard or Modified
Versions is governed by this Artistic License. By using, modifying or
distributing the Package, you accept this license. Do not use, modify,
or distribute the Package, if you do not accept this license.

If your Modified Version has been derived from a Modified Version made
by someone other than you, you are nevertheless required to ensure that
your Modified Version complies with the requirements of this license.

This license does not grant you the right to use any trademark, service
mark, tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge
patent license to make, have made, use, offer to sell, sell, import and
otherwise transfer the Package with respect to any patent claims
licensable by the Copyright Holder that are necessarily infringed by the
Package. If you institute patent litigation (including a cross-claim or
counterclaim) against any party alleging that the Package constitutes
direct or contributory patent infringement, then this Artistic License
to you shall terminate on the date that such litigation is filed.

Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

==> Config-Files-Simple-0.01.1.tar.gz: Config-Files-Simple-0.01.1/lib/Config/Files/Simple/JSON.pm <==
package Config::Files::Simple::JSON;

=encoding UTF-8
 
=head1 NAME
 
Config::Files::Simple::JSON - Yet another config file reader.

=head1 VERSION

version 0.01.1

=cut

our $VERSION = '0.01.1';    # VERSION

use utf8;
use strict;
use warnings;

=head1 SUBROUTINES/METHODS

=head2 new

Constructor

=cut

sub new {
    my $class = shift;
    my $self  = {};
    bless $self, $class;
}

=head2 config_file

Read configuration file from given path.

=cut

sub config_file {
    if ( !-f $_[1] ) {
        require Carp;
        Carp::cluck "could not find $_[1] file";
        return undef;
    }
    require String::Any::Extensions;
    if ( !String::Any::Extensions::include( $_[1], defined $_[2] ? $_[2] : ['.json'] ) ) {
        require Carp;
        Carp::cluck("$_[1] seems not to be a JSON file.");
    }
    require JSON::Parse;
    return JSON::Parse::json_file_to_perl( $_[1] );
}

1;

__END__

=pod
 
=head1 DESCRIPTION
 
JSON file reader for Config::Files::Simple.
 
=head1 AUTHOR

Mario Zieschang, C<< <mziescha at cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-Config-Files-Simple at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Config-Files-Simple>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Config::Files::Simple


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Config-Files-Simple>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Config-Files-Simple>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Config-Files-Simple>

=item * Search CPAN

L<http://search.cpan.org/dist/Config-Files-Simple/>

=back

=head1 LICENSE AND COPYRIGHT

Copyright 2016 Mario Zieschang.

This program is free software; you can redistribute it and/or modify it
under the terms of the the Artistic License (2.0). You may obtain a
copy of the full license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any use, modification, and distribution of the Standard or Modified
Versions is governed by this Artistic License. By using, modifying or
distributing the Package, you accept this license. Do not use, modify,
or distribute the Package, if you do not accept this license.

If your Modified Version has been derived from a Modified Version made
by someone other than you, you are nevertheless required to ensure that
your Modified Version complies with the requirements of this license.

This license does not grant you the right to use any trademark, service
mark, tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge
patent license to make, have made, use, offer to sell, sell, import and
otherwise transfer the Package with respect to any patent claims
licensable by the Copyright Holder that are necessarily infringed by the
Package. If you institute patent litigation (including a cross-claim or
counterclaim) against any party alleging that the Package constitutes
direct or contributory patent infringement, then this Artistic License
to you shall terminate on the date that such litigation is filed.

Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
